# enthalpy_estimator

A package to automatically generate reactions and estimate enthalpy.

## Installation

```bash
$ pip install enthalpy_estimator
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`enthalpy_estimator` was created by Egor Nosach. It is licensed under the terms of the GNU General Public License v3.0 license.

## Credits

`enthalpy_estimator` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
